## Copyright (C) 2018 - Patrick Troxler
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program. If not, see <http://www.gnu.org/licenses/>.

## Author: Patrick Troxler <patrick-troxler@hotmail.com>
## Created: 2018-06-26

## -*- texinfo -*-
## @defun {@var{u} =} delayrain (@var{dim}, @var{vdata},@var{delayv_samp})
## Creates a vector of delayed rainfall 
##
##with dimension @command{[dim, size(vdata,1)]} based
## on the delays taken from the vector delayv_samp (in number of samples). 
## The vector vdata contains rain intensities measurements (mm/h)
##
## @seealso{interp1}
## @end defun 

function u  = delayrain (dim, vdata, delayv_samp)
  
  Nt = size(vdata,1);
  tvector = 1:Nt;
  u = zeros (dim, Nt);
  for ii=1:dim
    u(ii,:) = interp1 (tvector' + delayv_samp(ii), vdata, tvector', ...
      'nearest', 'extrap').';
  endfor
endfunction
