## Copyright (C) 2018 - Patrick Troxler
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program. If not, see <http://www.gnu.org/licenses/>.

## Author: Patrick Troxler <patrick-troxler@hotmail.com>
## Created: 2018-06-19

## -*- texinfo -*-
## @defun {@var{k} =} kalmanfilter ()
## Combines functions kalmantrn and kalmantst
##
## @seealso{kalmantrn, kalmantst}
## @end defun 

function [ktrn ktst] = kalmanfilter (ktrn, param1, param2 ,...
                         kalmantype, trn_flag, tst_flag,...
                         v_tst, delayv_samp)
  
  % Pre-allocation
  if strcmp(ktrn.modeltype,'dynamic')
    dt                      = 10;
    dimx                    = size(ktrn.state_estimate,1)./2; 
    dimq                    = dimx;
    ktrn.transition_matrix  = blkdiag (eye (dimx), eye (dimq) .* (1 + param1 * dt)); % State transition matrix
    ktrn.input_matrix       = [zeros(dimx,dimq); diag(repmat(param2,dimq,1)*dt)]; % Input matrix
  endif
  
  if strcmp(ktrn.modeltype,'conceptual')
    dt                      = 10;
    dimx                    = size(ktrn.state_estimate,1);
    dimq                    = dimx;
    ktrn.transition_matrix  = blkdiag (eye (dimx) .* (1 - param1 * dt)); % State transition matrix
    ktrn.measurement_matrix = ones(1,dimx) .* param2 .* param1;
  endif
  
  if strcmp(ktrn.modeltype,'linear')
    dt                      = 10;
    dimx                    = size(ktrn.state_estimate,1);
  endif  

  
  ## Training
  #
  if trn_flag.record
    tic
    [ktrn, Mhist, Phist] = kalmantrn (ktrn,kalmantype,trn_flag);
    toc
    ktrn.Mhist = cat(2,ktrn.Mhist,Mhist);
    ktrn.Phist = cat(2,ktrn.Phist,Phist);
  else
    tic
    [ktrn] = kalmantrn (ktrn,kalmantype,trn_flag);
    toc
  end
   
  % Pre-allocation for testing
  ktst = ktrn;
  ktst.Mhist = []; % do not copy from training
  ktst.Phist = [];
  ktst.measurement_vector     = v_tst(:,end).';
  Nt_tst = size(ktst.measurement_vector,2);
  
  if strcmp(ktrn.modeltype,'linear')
  ktst.measurement_matrix = [];
    for ii=3:(size(v_tst,2)-1)
      ktst.measurement_matrix = cat (2, ktst.measurement_matrix, delayrain...
                                    (1, v_tst(:,ii), delayv_samp(ii-2))');
    endfor
  elseif strcmp(ktrn.modeltype,'dynamic')
    ktst.constant_input  = delayrain(dimq, v_tst(:,2), delayv_samp); %vector of delayed rainfall
  endif
 
 
  ## Testing
  #
  if tst_flag.record
    tic
    [ktst, Mhist, Phist] = kalmantst (ktst,kalmantype,tst_flag);
    toc
    ktst.Mhist = Mhist;
    ktst.Phist = Phist; 
  else
    tic
    ktst = kalmantst (ktst,kalmantype,tst_flag);
    toc
  end
  
endfunction
