## Copyright (C) 2018 - Patrick Troxler
## Copyright (C) 2018 - Juan Pablo Carbajal
## 
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program. If not, see <http://www.gnu.org/licenses/>.

## Author: Patrick Troxler <patrick-troxler@hotmail.com>
## Created: 2018-06-19

## -*- texinfo -*-
## @defun {@var{k} =} kalmanstruct ()
## Creates a structure which provides placeholders for inputs to kalman filter.
##
## (state estimate A, state covariance P, transition matrix A, process noise Q, 
## input matrix B, constant input u, measurement vector X, measurement matrix H, 
## measurement noise covariance R and derivate of H with respect to state)
##
## @seealso{kalmantrn, kalmantst}
## @end defun 

function k = kalmanstruct (varargin)

  FIELDS = {
  'state_estimate', ...           # X, Nx1 mean state estimate of previous step
  'state_covariance', ...         # P, NxN state covariance of previous step
  'transition_matrix', ...        # A, Transition matrix of discrete model
  'process_noise', ...            # Q, Process noise of discrete model
  'input_matrix', ...             # B, Input effect matrix
  'measurement_matrix', ...       # H, Measurement matrix
  'measurement_covariance', ...   # R, Measurement noise covariance
  'H_derivative_state', ...       # V, Derivative of h() with respect to noise as matrix
  'predictive_mean', ...          # MU, Predictive mean of Y
  'predictive_covariance', ...    # S, Predictive covariance of Y
  'kalmantype', ...               # prediction and update type (classical, extended, ...)
  };
  

  p = inputParser();
  p.FunctionName = 'kalmanstruct';
  for field = FIELDS
    p.addParameter(field{1}, []);
  endfor
  p.parse(varargin{:})
  
  k = p.Results;
  
endfunction
 
